Learn R Programming

upwaver (version 1.2.1)

board_details: Information about a specific board

Description

board_details() is a wrapper around "board_details" as specified in the 'Upwave' API https://www.upwave.io/api/. It returns detailed information about a specific board such as id, title, purpose, background image, creation time, creator, columns, rows and colors.

Usage

board_details(organisation, board_id, token)

Arguments

organisation

A character. The name of the organisation as specified in the URL: https://<organisation>.upwave.io

board_id

An integer. The number of the board you want to inspect as specified in the URL: https://<organisation>.upwave.io/board/<board_id>/view/

token

A character. The API token to access boards on upwave.io. The token can be obtained by visiting your account settings. Click your profile image, select "Settings" and find your API-Key in the "Account" tab.

Value

A list

Examples

Run this code
# NOT RUN {
board_details("4597", 14351, "807a0c3451c04602b4dbfdc0338a65f7")
# }

Run the code above in your browser using DataLab