Learn R Programming

upwaver (version 1.2.1)

content_as_list: Transform the answer of a 'Upwave' API request to a list

Description

content_as_list() is an internal function that extracts content from a request and coerces it to a list format

Usage

content_as_list(response)

Arguments

response

An object of class "response"; response of a GET request

Value

A list