storypoints_and_status: Calculate storypoints ans status of the Cards of a specific Board
Description
Calculates storypoints (of active Cards, which are Cards that haven't been completed
yet) and status in the backlog of an 'Upwave' board.
Storypoints have to be specified in the description (directly beneath the title) of
each card with a string of the form: "Aufwand: X SP" or "Aufwand: X AT". This is not
part of the 'Upwave' API but an additional functionality.
A character. The name of the organisation as specified in the URL:
https://<organisation>.upwave.io
board_id
An integer. The number of the board you want to inspect as specified in
the URL: https://<organisation>.upwave.io/board/<board_id>/view/
token
A character. The API token to access boards on upwave.io. The token can be
obtained by visiting your account settings. Click your profile image, select "Settings"
and find your API-Key in the "Account" tab.
Value
A list containing a data.frame with all storypoints and the status per card and
the numeric sum_storypoints.