Learn R Programming

upwaver (version 1.2.1)

storypoints_and_status_released: Calculate storypoints ans status of the Cards of a specific Board

Description

Calculates storypoints of released cards on a specific board

Usage

storypoints_and_status_released(organisation, board_id, token)

Arguments

organisation

A character. The name of the organisation as specified in the URL: https://<organisation>.upwave.io

board_id

An integer. The number of the board you want to inspect as specified in the URL: https://<organisation>.upwave.io/board/<board_id>/view/

token

A character. The API token to access boards on upwave.io. The token can be obtained by visiting your account settings. Click your profile image, select "Settings" and find your API-Key in the "Account" tab.

Value

A list containing a data.frame with all storypoints and the status per card and the numeric sum_storypoints.

Examples

Run this code
# NOT RUN {
upwaver::storypoints_and_status_released(
"4597", 14351, "807a0c3451c04602b4dbfdc0338a65f7")
# }

Run the code above in your browser using DataLab