board_details() is a wrapper around "board_details" as specified in the 'Upwave' API
https://www.upwave.io/api/. It returns detailed information about a specific board such
as id, title, purpose, background image, creation time, creator, columns, rows and colors.