list_boards: Information about your organisation's boards
Description
list_boards() is a wrapper around "List Boards" as specified in the 'Upwave' API
https://www.upwave.io/api/. It returns information for your organisation's
boards as id's, title's, time of creation and the users who created the boards.
Usage
list_boards(organisation, token)
Arguments
organisation
A character. The name of the organisation as specified in the URL:
https://<organisation>.upwave.io
token
A character. The API token to access boards on upwave.io. The token can be
obtained by visiting your account settings. Click your profile image, select "Settings"
and find your API-Key in the "Account" tab.