list_cards: Information about the cards on a board
Description
list_cards() is wrapper around "List Cards" as specified in the 'Upwave' API
https://www.upwave.io/api/. It returns detailed Information about each card of a specific
board as card id, title, board id, description, due_dt, state, color, assigned, ...
Usage
list_cards(organisation, board_id, token)
Arguments
organisation
A character. The name of the organisation as specified in the URL:
https://<organisation>.upwave.io
board_id
An integer. The number of the board you want to inspect as specified in
the URL: https://<organisation>.upwave.io/board/<board_id>/view/
token
A character. The API token to access boards on upwave.io. The token can be
obtained by visiting your account settings. Click your profile image, select "Settings"
and find your API-Key in the "Account" tab.