A character. The name of the organisation as specified in the URL:
https://<organisation>.upwave.io
board_id
An integer. The number of the board you want to inspect as specified in
the URL: https://<organisation>.upwave.io/board/<board_id>/view/
token
A character. The API token to access boards on upwave.io. The token can be
obtained by visiting your account settings. Click your profile image, select "Settings"
and find your API-Key in the "Account" tab.
Value
A list containing a data.frame with all storypoints and the status per card and
the numeric sum_storypoints.